==> interactive-style-1.5.0.tgz: package/src/components/Colors/example.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Page from 'Common/Page/';
import CodeBlock from 'Common/CodeBlock';

import * as COLORS from 'Constants/colors/index.js';
import Table from './Table';

console.log(COLORS);

class App extends React.Component {
  render() {
    return (
      <Page title='Colors' well='800px'>
        <p style={{ maxWidth: '800px' }}>
          You can use the colors from this module in either SCSS files or JS files. To use all the SCSS variables, import the <code>vars.scss</code> file from this libaray. In JavaScript you can import the color object which breaks down by category. Check the reference below for color names in both languages.
        </p>

        <CodeBlock
          value={`/* ---- SCSS---- */
@import "~@politico/interactive-style/vars.scss";

p {
  color: $politico-red;
}


/* ---- JavaScript---- */
import { COLORS } from '@politico/interactive-style';

<p style={{color: COLORS.BRAND.POLITICO_RED}}>POLITICO</p>
        `}
        />

        <Table
          name='Brand Colors'
          reference='COLORS.BRAND.X'
          colors={COLORS.BRAND}
        />

        <Table
          name='Base Colors'
          reference='COLORS.BASE.X'
          colors={COLORS.BASE}
        />

        <Table
          name='Election Colors'
          reference='COLORS.ELECTIONS.X'
          colors={COLORS.ELECTIONS}
        />

        <Table
          name='Democrat Colors'
          reference='COLORS.ELECTIONS.DEM_ALTS[X]'
          colors={COLORS.ELECTIONS.DEM_ALTS}
          minor
        />

        <Table
          name='Republican Colors'
          reference='COLORS.ELECTIONS.GOP_ALTS[X]'
          colors={COLORS.ELECTIONS.GOP_ALTS}
          minor
        />

        <Table
          name='Dem To GOP Ramp'
          reference='COLORS.ELECTIONS.DEM_TO_GOP[X]'
          colors={COLORS.ELECTIONS.DEM_TO_GOP}
          minor
        />

        <Table
          name='Diverging Color Scale'
          reference='COLORS.DIVERGING.X'
          colors={COLORS.DIVERGING}
        />

        <Table
          name='Teal To Dirt Ramp'
          reference='COLORS.DIVERGING.TEAL_TO_DIRT[X]'
          colors={COLORS.DIVERGING.TEAL_TO_DIRT}
          minor
        />

        <Table
          name='Moss To Sapphire Ramp'
          reference='COLORS.DIVERGING.MOSS_TO_SHAPPIRE[X]'
          colors={COLORS.DIVERGING.MOSS_TO_SHAPPIRE}
          minor
        />

        <Table
          name='Qualitative Color Scale'
          reference='COLORS.QUALITATIVE.X'
          colors={COLORS.QUALITATIVE}
        />

        <Table
          name='4-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q4.X'
          colors={COLORS.QUALITATIVE.Q4}
          noCSS
        />

        <Table
          name='6-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q6.X'
          colors={COLORS.QUALITATIVE.Q6}
          noCSS
        />

        <Table
          name='7-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q7.X'
          colors={COLORS.QUALITATIVE.Q7}
          noCSS
        />

        <Table
          name='Sequential Color Scale'
          reference='COLORS.SEQUENTIAL.X'
          colors={COLORS.SEQUENTIAL}
        />

        <Table
          name='Money To Foam Ramp'
          reference='COLORS.SEQUENTIAL.MONEY_TO_FOAM[X]'
          colors={COLORS.SEQUENTIAL.MONEY_TO_FOAM}
          minor
        />

        <Table
          name='Sangria To Peach Ramp'
          reference='COLORS.SEQUENTIAL.SANGRIA_TO_PEACH[X]'
          colors={COLORS.SEQUENTIAL.SANGRIA_TO_PEACH}
          minor
        />

        <Table
          name='Red To Yellow Ramp'
          reference='COLORS.SEQUENTIAL.RED_TO_YELLOW[X]'
          colors={COLORS.SEQUENTIAL.RED_TO_YELLOW}
          minor
        />
      </Page>
    );
  }
}

export default App;

ReactDOM.render(<App />, document.getElementById('app'));

==> interactive-style-1.6.1.tgz: package/src/components/Colors/example.js <==
import React from 'react';
import ReactDOM from 'react-dom';
import Page from 'Common/Page/';
import CodeBlock from 'Common/CodeBlock';

import * as COLORS from 'Constants/colors/index.js';
import Table from './Table';

console.log(COLORS);

class App extends React.Component {
  render() {
    return (
      <Page title='Colors' well='800px'>
        <p style={{ maxWidth: '800px' }}>
          You can use the colors from this module in either SCSS files or JS files. To use all the SCSS variables, import the <code>vars.scss</code> file from this libaray. In JavaScript you can import the color object which breaks down by category. Check the reference below for color names in both languages.
        </p>

        <CodeBlock
          value={`/* ---- SCSS---- */
@import "~@politico/interactive-style/vars.scss";

p {
  color: $politico-red;
}


/* ---- JavaScript---- */
import { COLORS } from '@politico/interactive-style';

<p style={{color: COLORS.BRAND.POLITICO_RED}}>POLITICO</p>
        `}
        />

        <Table
          name='Brand Colors'
          reference='COLORS.BRAND.X'
          colors={COLORS.BRAND}
        />

        <Table
          name='Base Colors'
          reference='COLORS.BASE.X'
          colors={COLORS.BASE}
        />

        <Table
          name='Election Colors'
          reference='COLORS.ELECTIONS.X'
          colors={COLORS.ELECTIONS}
        />

        <Table
          name='Democrat Colors'
          reference='COLORS.ELECTIONS.DEM_ALTS[X]'
          colors={COLORS.ELECTIONS.DEM_ALTS}
          minor
        />

        <Table
          name='Republican Colors'
          reference='COLORS.ELECTIONS.GOP_ALTS[X]'
          colors={COLORS.ELECTIONS.GOP_ALTS}
          minor
        />

        <Table
          name='Dem To GOP Ramp'
          reference='COLORS.ELECTIONS.DEM_TO_GOP[X]'
          colors={COLORS.ELECTIONS.DEM_TO_GOP}
          minor
        />

        <Table
          name='Diverging Color Scale'
          reference='COLORS.DIVERGING.X'
          colors={COLORS.DIVERGING}
        />

        <Table
          name='Teal To Dirt Ramp'
          reference='COLORS.DIVERGING.TEAL_TO_DIRT[X]'
          colors={COLORS.DIVERGING.TEAL_TO_DIRT}
          minor
        />

        <Table
          name='Moss To Sapphire Ramp'
          reference='COLORS.DIVERGING.MOSS_TO_SAPPHIRE[X]'
          colors={COLORS.DIVERGING.MOSS_TO_SAPPHIRE}
          minor
        />

        <Table
          name='Qualitative Color Scale'
          reference='COLORS.QUALITATIVE.X'
          colors={COLORS.QUALITATIVE}
        />

        <Table
          name='4-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q4.X'
          colors={COLORS.QUALITATIVE.Q4}
          noCSS
        />

        <Table
          name='6-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q6.X'
          colors={COLORS.QUALITATIVE.Q6}
          noCSS
        />

        <Table
          name='7-Item Qualitative Scale'
          reference='COLORS.QUALITATIVE.Q7.X'
          colors={COLORS.QUALITATIVE.Q7}
          noCSS
        />

        <Table
          name='Sequential Color Scale'
          reference='COLORS.SEQUENTIAL.X'
          colors={COLORS.SEQUENTIAL}
        />

        <Table
          name='Money To Foam Ramp'
          reference='COLORS.SEQUENTIAL.MONEY_TO_FOAM[X]'
          colors={COLORS.SEQUENTIAL.MONEY_TO_FOAM}
          minor
        />

        <Table
          name='Sangria To Peach Ramp'
          reference='COLORS.SEQUENTIAL.SANGRIA_TO_PEACH[X]'
          colors={COLORS.SEQUENTIAL.SANGRIA_TO_PEACH}
          minor
        />

        <Table
          name='Red To Yellow Ramp'
          reference='COLORS.SEQUENTIAL.RED_TO_YELLOW[X]'
          colors={COLORS.SEQUENTIAL.RED_TO_YELLOW}
          minor
        />
      </Page>
    );
  }
}

export default App;

ReactDOM.render(<App />, document.getElementById('app'));
